<?php

namespace Bixo\Listing\Workflow;

use Bixo\Listing\Models\Referral;
use Validator;

class ReferralValidator
{

    /**
     * Determine if the given referral is valid for complete status.
     *
     * @param Referral $referral
     *
     * @return bool / Validator
     */
    public function complete(Referral $referral)
    {
        return Validator::make($referral->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given referral is valid for verify status.
     *
     * @param Referral $referral
     *
     * @return bool / Validator
     */
    public function verify(Referral $referral)
    {
        return Validator::make($referral->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given referral is valid for approve status.
     *
     * @param Referral $referral
     *
     * @return bool / Validator
     */
    public function approve(Referral $referral)
    {
        return Validator::make($referral->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given referral is valid for publish status.
     *
     * @param Referral $referral
     *
     * @return bool / Validator
     */
    public function publish(Referral $referral)
    {
        return Validator::make($referral->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given referral is valid for archive status.
     *
     * @param Referral $referral
     *
     * @return bool / Validator
     */
    public function archive(Referral $referral)
    {
        return Validator::make($referral->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given referral is valid for unpublish status.
     *
     * @param Referral $referral
     *
     * @return bool / Validator
     */
    public function unpublish(Referral $referral)
    {
        return Validator::make($referral->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
